@@ -4,11 +4,12 @@ To run in CLI mode.
 """
 from pygeoweaver import detail_host, detail_process, detail_workflow, export_workflow, \
     show_history, import_workflow, list_hosts, list_processes, list_workflows, \
-    start, stop, reset_password, run_process, run_worklfow
+    start, stop, reset_password, run_process, run_worklfow, helpwith, ui
+from pygeoweaver.server import show
 
 def main():
     # start geoweaver
-    start()
+    # start()
     # stop geoweaver
     # stop()
     # list resources
@@ -37,6 +38,8 @@ def main():
 
     # reset localhost password for Geoweaver
     # reset_password()
+    show()
+    # helpwith()
 
 
 if __name__ == "__main__":
